=======
Credits
=======

Development Lead
----------------

* Kirill Klenov <horneds@gmail.com>

Contributors
------------

* Andrew Grigorev (https://github.com/ei-grad)
* Arthur Darcet (https://github.com/arthurdarcet)
* Christophe (https://github.com/syrkit)
* Dima Moroz (https://github.com/dmrz)
* Don Brown (https://github.com/mrdon)
* Liz (https://github.com/stillinbeta)
* Peyman Mortazavi (https://github.com/peymanmortazavi)
* Bajusz Tamás (https://github.com/gbtami)
* sunghyun-lee (https://github.com/sunghyun-lee)
* Bajusz Tamás (https://github.com/gbtami)
* Dougal Matthews (https://github.com/d0ugal)
* Lefteris Chatzimparmpas (https://github.com/lefcha)
